@@ -3,7 +3,7 @@
 #[cfg(feature = "v2_16")]
 use super::{NetworkProxyMode, NetworkProxySettings};
 #[cfg(feature = "v2_6")]
-use glib::translate::*;
+use glib::translate::{FromGlibPtrNone, IntoGlib, ToGlibPtr, ToGlibPtrMut};
 use glib::IsA;
 
 use super::WebContext;
